@@ -524,8 +524,12 @@ class CmdStanConverter:
             )
             attrs = None
         return (
-            dict_to_dataset(data, coords=self.coords, dims=self.dims, attrs=attrs),
-            dict_to_dataset(data_warmup, coords=self.coords, dims=self.dims, attrs=attrs),
+            dict_to_dataset(
+                data, coords=self.coords, dims=self.dims, attrs=attrs, skip_event_dims=True
+            ),
+            dict_to_dataset(
+                data_warmup, coords=self.coords, dims=self.dims, attrs=attrs, skip_event_dims=True
+            ),
         )
 
     def to_inference_data(self):
@@ -797,7 +801,7 @@ def from_cmdstan(
     """Convert CmdStan data into an InferenceData object.
 
     For a usage example read the
-    :doc:`Cookbook section on from_cmdstan </notebooks/InferenceDataCookbook>`
+    :ref:`Cookbook section on from_cmdstan <cookbook>`
 
     Parameters
     ----------
