@@ -138,10 +138,20 @@ class DictConverter:
 
         return (
             dict_to_dataset(
-                data, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+                data,
+                library=None,
+                coords=self.coords,
+                dims=self.dims,
+                attrs=self.attrs,
+                skip_event_dims=True,
             ),
             dict_to_dataset(
-                data_warmup, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+                data_warmup,
+                library=None,
+                coords=self.coords,
+                dims=self.dims,
+                attrs=self.attrs,
+                skip_event_dims=True,
             ),
         )
 
@@ -303,7 +313,7 @@ def from_dict(
     """Convert Dictionary data into an InferenceData object.
 
     For a usage example read the
-    :doc:`Cookbook section on from_dict </notebooks/InferenceDataCookbook>`
+    :ref:`Cookbook section on from_dict <cookbook>`
 
     Parameters
     ----------
