@@ -314,7 +314,7 @@ def from_pyjags(
     Takes a python dictionary of samples that has been generated by the sample
     method of a model instance and returns an Arviz inference data object.
     For a usage example read the
-    :doc:`Cookbook section on from_pyjags </notebooks/InferenceDataCookbook>`
+    :ref:`Cookbook section on from_pyjags <cookbook>`
 
     Parameters
     ----------
