@@ -65,6 +65,7 @@ class PyMC3Converter:  # pylint: disable=too-many-instance-attributes
         dims: Optional[Dims] = None,
         model=None,
         save_warmup: Optional[bool] = None,
+        density_dist_obs: bool = True,
     ):
         import pymc3
         import theano
@@ -158,6 +159,7 @@ class PyMC3Converter:  # pylint: disable=too-many-instance-attributes
             model_dims = {k: list(v) for k, v in self.model.RV_dims.items()}
             self.dims = {**model_dims, **self.dims}
 
+        self.density_dist_obs = density_dist_obs
         self.observations, self.multi_observations = self.find_observations()
 
     def find_observations(self) -> Tuple[Optional[Dict[str, Var]], Optional[Dict[str, Var]]]:
@@ -169,7 +171,7 @@ class PyMC3Converter:  # pylint: disable=too-many-instance-attributes
         for obs in self.model.observed_RVs:
             if hasattr(obs, "observations"):
                 observations[obs.name] = obs.observations
-            elif hasattr(obs, "data"):
+            elif hasattr(obs, "data") and self.density_dist_obs:
                 for key, val in obs.data.items():
                     multi_observations[key] = val.eval() if hasattr(val, "eval") else val
         return observations, multi_observations
@@ -318,8 +320,16 @@ class PyMC3Converter:  # pylint: disable=too-many-instance-attributes
             except TypeError:
                 warnings.warn(warn_msg)
         return (
-            dict_to_dataset(data, library=self.pymc3, dims=self.dims, coords=self.coords),
-            dict_to_dataset(data_warmup, library=self.pymc3, dims=self.dims, coords=self.coords),
+            dict_to_dataset(
+                data, library=self.pymc3, dims=self.dims, coords=self.coords, skip_event_dims=True
+            ),
+            dict_to_dataset(
+                data_warmup,
+                library=self.pymc3,
+                dims=self.dims,
+                coords=self.coords,
+                skip_event_dims=True,
+            ),
         )
 
     def translate_posterior_predictive_dict_to_xarray(self, dct) -> xr.Dataset:
@@ -410,7 +420,11 @@ class PyMC3Converter:  # pylint: disable=too-many-instance-attributes
         # The constant data vars must be either pm.Data (TensorSharedVariable) or pm.Deterministic
         constant_data_vars = {}  # type: Dict[str, Var]
         for var in self.model.deterministics:
-            ancestors = self.theano.tensor.gof.graph.ancestors(var.owner.inputs)
+            if hasattr(self.theano, "gof"):
+                ancestors_func = self.theano.gof.graph.ancestors  # pylint: disable=no-member
+            else:
+                ancestors_func = self.theano.graph.basic.ancestors  # pylint: disable=no-member
+            ancestors = ancestors_func(var.owner.inputs)
             # no dependency on a random variable
             if not any((isinstance(a, self.pymc3.model.PyMC3Variable) for a in ancestors)):
                 constant_data_vars[var.name] = var
@@ -492,13 +506,14 @@ def from_pymc3(
     dims: Optional[DimSpec] = None,
     model: Optional[Model] = None,
     save_warmup: Optional[bool] = None,
+    density_dist_obs: bool = True,
 ) -> InferenceData:
     """Convert pymc3 data into an InferenceData object.
 
     All three of them are optional arguments, but at least one of ``trace``,
     ``prior`` and ``posterior_predictive`` must be present.
     For a usage example read the
-    :doc:`Cookbook section on from_pymc3 </notebooks/InferenceDataCookbook>`
+    :ref:`Cookbook section on from_pymc3 <cookbook>`
 
     Parameters
     ----------
@@ -524,6 +539,9 @@ def from_pymc3(
     save_warmup : bool, optional
         Save warmup iterations InferenceData object. If not defined, use default
         defined by the rcParams.
+    density_dist_obs : bool, default True
+        Store variables passed with ``observed`` arg to
+        :class:`pymc3:pymc.distributions.DensityDist` in the generated InferenceData.
 
     Returns
     -------
@@ -538,6 +556,7 @@ def from_pymc3(
         dims=dims,
         model=model,
         save_warmup=save_warmup,
+        density_dist_obs=density_dist_obs,
     ).to_inference_data()
 
 
