@@ -1,5 +1,6 @@
 """Pyro-specific conversion code."""
 import logging
+from typing import Callable, Optional
 import warnings
 
 import numpy as np
@@ -18,7 +19,7 @@ class PyroConverter:
 
     # pylint: disable=too-many-instance-attributes
 
-    model = None  # type: Optional[callable]
+    model = None  # type: Optional[Callable]
     nchains = None  # type: int
     ndraws = None  # type: int
 
@@ -154,7 +155,9 @@ class PyroConverter:
                     "Check your model vectorization or set log_likelihood=False"
                 )
                 return None
-        return dict_to_dataset(data, library=self.pyro, coords=self.coords, dims=self.dims)
+        return dict_to_dataset(
+            data, library=self.pyro, coords=self.coords, dims=self.dims, skip_event_dims=True
+        )
 
     def translate_posterior_predictive_dict_to_xarray(self, dct, dims):
         """Convert posterior_predictive or prediction samples to xarray."""
@@ -295,7 +298,7 @@ def from_pyro(
     """Convert Pyro data into an InferenceData object.
 
     For a usage example read the
-    :doc:`Cookbook section on from_pyro </notebooks/InferenceDataCookbook>`
+    :ref:`Cookbook section on from_pyro <cookbook>`
 
     Parameters
     ----------
