@@ -13,6 +13,14 @@ from ..rcparams import rcParams
 from .base import dict_to_dataset, generate_dims_coords, make_attrs, requires
 from .inference_data import InferenceData
 
+try:
+    import ujson as json
+except ImportError:
+    # Can't find ujson using json
+    # mypy struggles with conditional imports expressed as catching ImportError:
+    # https://github.com/python/mypy/issues/1153
+    import json  # type: ignore
+
 
 class PyStanConverter:
     """Encapsulate PyStan specific logic."""
@@ -137,8 +145,16 @@ class PyStanConverter:
         }
 
         return (
-            dict_to_dataset(data, library=self.pystan, coords=self.coords, dims=self.dims),
-            dict_to_dataset(data_warmup, library=self.pystan, coords=self.coords, dims=self.dims),
+            dict_to_dataset(
+                data, library=self.pystan, coords=self.coords, dims=self.dims, skip_event_dims=True
+            ),
+            dict_to_dataset(
+                data_warmup,
+                library=self.pystan,
+                coords=self.coords,
+                dims=self.dims,
+                skip_event_dims=True,
+            ),
         )
 
     @requires("posterior")
@@ -665,10 +681,13 @@ def get_attrs(fit):
         for arg in attrs["args"]:
             if isinstance(arg["init"], bytes):
                 arg["init"] = arg["init"].decode("utf-8")
+        attrs["args"] = json.dumps(attrs["args"])
     try:
         attrs["inits"] = [holder.inits for holder in fit.sim["samples"]]
     except Exception as exp:  # pylint: disable=broad-except
         _log.warning("Failed to fetch `args` from fit: %s", exp)
+    else:
+        attrs["inits"] = json.dumps(attrs["inits"])
 
     attrs["step_size"] = []
     attrs["metric"] = []
@@ -706,6 +725,7 @@ def get_attrs(fit):
 
         attrs["metric"].append(metric)
         attrs["inv_metric"].append(inv_metric)
+    attrs["inv_metric"] = json.dumps(attrs["inv_metric"])
 
     if not attrs["step_size"]:
         del attrs["step_size"]
@@ -848,7 +868,7 @@ def from_pystan(
     """Convert PyStan data into an InferenceData object.
 
     For a usage example read the
-    :doc:`Cookbook section on from_pystan </notebooks/InferenceDataCookbook>`
+    :ref:`Cookbook section on from_pystan <cookbook>`
 
     Parameters
     ----------
