@@ -2,9 +2,9 @@
 import matplotlib.pyplot as plt
 import numpy as np
 
-from . import backend_show
 from ....stats import autocorr
-from ...plot_utils import _create_axes_grid, make_label
+from ...plot_utils import _scale_fig_size, make_label
+from . import backend_kwarg_defaults, backend_show, create_axes_grid
 
 
 def plot_autocorr(
@@ -14,30 +14,38 @@ def plot_autocorr(
     figsize,
     rows,
     cols,
-    linewidth,
-    titlesize,
     combined,
-    xt_labelsize,
+    textsize,
     backend_kwargs,
     show,
 ):
     """Matplotlib autocorrplot."""
+    if backend_kwargs is None:
+        backend_kwargs = {}
+
+    backend_kwargs = {
+        **backend_kwarg_defaults(),
+        **backend_kwargs,
+    }
+
+    figsize, _, titlesize, xt_labelsize, linewidth, _ = _scale_fig_size(
+        figsize, textsize, rows, cols
+    )
+
+    backend_kwargs.setdefault("figsize", figsize)
+    backend_kwargs.setdefault("sharex", True)
+    backend_kwargs.setdefault("sharey", True)
+    backend_kwargs.setdefault("squeeze", True)
+
     if axes is None:
-        _, axes = _create_axes_grid(
+        _, axes = create_axes_grid(
             len(plotters),
             rows,
             cols,
-            figsize=figsize,
-            squeeze=False,
-            sharex=True,
-            sharey=True,
-            backend="matplotlib",
             backend_kwargs=backend_kwargs,
         )
 
-    axes = np.atleast_2d(axes)  # in case of only 1 plot
-
-    for (var_name, selection, x), ax in zip(plotters, axes.flatten()):
+    for (var_name, selection, x), ax in zip(plotters, np.ravel(axes)):
         x_prime = x
         if combined:
             x_prime = x.flatten()
@@ -47,9 +55,9 @@ def plot_autocorr(
         ax.set_title(make_label(var_name, selection), fontsize=titlesize, wrap=True)
         ax.tick_params(labelsize=xt_labelsize)
 
-    if axes.size > 0:
-        axes[0, 0].set_xlim(0, max_lag)
-        axes[0, 0].set_ylim(-1, 1)
+    if np.asarray(axes).size > 0:
+        np.asarray(axes).item(0).set_xlim(0, max_lag)
+        np.asarray(axes).item(0).set_ylim(-1, 1)
 
     if backend_show(show):
         plt.show()
