@@ -1,17 +1,17 @@
 """Matplotlib forestplot."""
-from collections import defaultdict, OrderedDict
+from collections import OrderedDict, defaultdict
 from itertools import tee
 
 import matplotlib.pyplot as plt
-from matplotlib.colors import to_rgba
 import numpy as np
+from matplotlib.colors import to_rgba
 
-from . import backend_kwarg_defaults, backend_show
 from ....stats import hdi
+from ....stats.density_utils import get_bins, histogram, kde
 from ....stats.diagnostics import _ess, _rhat
-from ....numeric_utils import _fast_kde, histogram, get_bins
-from ...plot_utils import _scale_fig_size, xarray_var_iter, make_label
 from ....utils import conditional_jit
+from ...plot_utils import _scale_fig_size, make_label, xarray_var_iter
+from . import backend_kwarg_defaults, backend_show
 
 
 def pairwise(iterable):
@@ -40,11 +40,13 @@ def plot_forest(
     ridgeplot_overlap,
     ridgeplot_alpha,
     ridgeplot_kind,
+    ridgeplot_truncate,
     ridgeplot_quantiles,
     textsize,
     ess,
     r_hat,
     backend_kwargs,
+    backend_config,  # pylint: disable=unused-argument
     show,
 ):
     """Matplotlib forest plot."""
@@ -91,14 +93,24 @@ def plot_forest(
     axes = np.atleast_1d(axes)
     if kind == "forestplot":
         plot_handler.forestplot(
-            hdi_prob, quartiles, xt_labelsize, titlesize, linewidth, markersize, axes[0], rope,
+            hdi_prob,
+            quartiles,
+            xt_labelsize,
+            titlesize,
+            linewidth,
+            markersize,
+            axes[0],
+            rope,
         )
     elif kind == "ridgeplot":
         plot_handler.ridgeplot(
+            hdi_prob,
             ridgeplot_overlap,
             linewidth,
+            markersize,
             ridgeplot_alpha,
             ridgeplot_kind,
+            ridgeplot_truncate,
             ridgeplot_quantiles,
             axes[0],
         )
@@ -218,34 +230,54 @@ class PlotHandler:
 
         return label_idxs()
 
-    def display_multiple_ropes(self, rope, ax, y, linewidth, rope_var):
+    def display_multiple_ropes(self, rope, ax, y, linewidth, var_name, selection):
         """Display ROPE when more than one interval is provided."""
-        vals = dict(rope[rope_var][0])["rope"]
-        ax.plot(
-            vals,
-            (y + 0.05, y + 0.05),
-            lw=linewidth * 2,
-            color="C2",
-            solid_capstyle="round",
-            zorder=0,
-            alpha=0.7,
-        )
-        return ax
+        for sel in rope.get(var_name, []):
+            # pylint: disable=line-too-long
+            if all(k in selection and selection[k] == v for k, v in sel.items() if k != "rope"):
+                vals = sel["rope"]
+                ax.plot(
+                    vals,
+                    (y + 0.05, y + 0.05),
+                    lw=linewidth * 2,
+                    color="C2",
+                    solid_capstyle="round",
+                    zorder=0,
+                    alpha=0.7,
+                )
+                return ax
 
-    def ridgeplot(self, mult, linewidth, alpha, ridgeplot_kind, ridgeplot_quantiles, ax):
+    def ridgeplot(
+        self,
+        hdi_prob,
+        mult,
+        linewidth,
+        markersize,
+        alpha,
+        ridgeplot_kind,
+        ridgeplot_truncate,
+        ridgeplot_quantiles,
+        ax,
+    ):
         """Draw ridgeplot for each plotter.
 
         Parameters
         ----------
+        hdi_prob : float
+            Probability for the highest density interval.
         mult : float
             How much to multiply height by. Set this to greater than 1 to have some overlap.
         linewidth : float
             Width of line on border of ridges
+        markersize : float
+            Size of marker in center of forestplot line
         alpha : float
             Transparency of ridges
         ridgeplot_kind : string
             By default ("auto") continuous variables are plotted using KDEs and discrete ones using
             histograms. To override this use "hist" to plot histograms and "density" for KDEs
+        ridgeplot_truncate: bool
+            Whether to truncate densities according to the value of hdi_prop. Defaults to True
         ridgeplot_quantiles: list
             Quantiles in ascending order used to segment the KDE. Use [.25, .5, .75] for quartiles.
             Defaults to None.
@@ -256,39 +288,64 @@ class PlotHandler:
             alpha = 1.0
         zorder = 0
         for plotter in self.plotters.values():
-            for x, y_min, y_max, y_q, color in plotter.ridgeplot(mult, ridgeplot_kind):
+            for x, y_min, y_max, hdi_, y_q, color in plotter.ridgeplot(
+                hdi_prob, mult, ridgeplot_kind
+            ):
                 if alpha == 0:
                     border = color
                     facecolor = "None"
                 else:
                     border = "k"
-                    facecolor = to_rgba(color, alpha)
                 if x.dtype.kind == "i":
+                    if ridgeplot_truncate:
+                        facecolor = to_rgba(color, alpha)
+                        y_max = y_max[(x >= hdi_[0]) & (x <= hdi_[1])]
+                        x = x[(x >= hdi_[0]) & (x <= hdi_[1])]
+                    else:
+                        facecolor = [
+                            to_rgba(color, alpha) if ci else "None"
+                            for ci in ((x >= hdi_[0]) & (x <= hdi_[1]))
+                        ]
+                    y_min = np.ones_like(x) * y_min
                     ax.bar(
                         x,
                         y_max - y_min,
                         bottom=y_min,
                         linewidth=linewidth,
                         ec=border,
-                        fc=facecolor,
+                        color=facecolor,
+                        alpha=None,
                         zorder=zorder,
                     )
                 else:
-                    if ridgeplot_quantiles is not None:
-                        idx = [np.sum(y_q < quant) for quant in ridgeplot_quantiles]
-                        ax.fill_between(
-                            x,
-                            y_min,
-                            y_max,
-                            where=np.isin(x, x[idx], invert=True, assume_unique=True),
-                            alpha=alpha,
-                            color=color,
-                            zorder=zorder,
+                    tr_x = x[(x >= hdi_[0]) & (x <= hdi_[1])]
+                    tr_y_min = np.ones_like(tr_x) * y_min
+                    tr_y_max = y_max[(x >= hdi_[0]) & (x <= hdi_[1])]
+                    y_min = np.ones_like(x) * y_min
+                    if ridgeplot_truncate:
+                        ax.plot(
+                            tr_x, tr_y_max, "-", linewidth=linewidth, color=border, zorder=zorder
+                        )
+                        ax.plot(
+                            tr_x, tr_y_min, "-", linewidth=linewidth, color=border, zorder=zorder
                         )
                     else:
                         ax.plot(x, y_max, "-", linewidth=linewidth, color=border, zorder=zorder)
                         ax.plot(x, y_min, "-", linewidth=linewidth, color=border, zorder=zorder)
-                        ax.fill_between(x, y_min, y_max, alpha=alpha, color=color, zorder=zorder)
+                    ax.fill_between(
+                        tr_x, tr_y_max, tr_y_min, alpha=alpha, color=color, zorder=zorder
+                    )
+
+                if ridgeplot_quantiles is not None:
+                    quantiles = [x[np.sum(y_q < quant)] for quant in ridgeplot_quantiles]
+                    ax.plot(
+                        quantiles,
+                        np.ones_like(quantiles) * y_min[0],
+                        "d",
+                        mfc=border,
+                        mec=border,
+                        ms=markersize,
+                    )
                 zorder -= 1
         return ax
 
@@ -300,7 +357,7 @@ class PlotHandler:
         Parameters
         ----------
         hdi_prob : float
-            How wide each line should be
+            Probability for the highest density interval. Width of each line.
         quartiles : bool
             Whether to mark quartiles
         xt_textsize : float
@@ -322,9 +379,9 @@ class PlotHandler:
             qlist = [endpoint, 50, 100 - endpoint]
 
         for plotter in self.plotters.values():
-            for y, rope_var, values, color in plotter.treeplot(qlist, hdi_prob):
+            for y, selection, values, color in plotter.treeplot(qlist, hdi_prob):
                 if isinstance(rope, dict):
-                    self.display_multiple_ropes(rope, ax, y, linewidth, rope_var)
+                    self.display_multiple_ropes(rope, ax, y, linewidth, plotter.var_name, selection)
 
                 mid = len(values) // 2
                 param_iter = zip(
@@ -448,6 +505,7 @@ class VarHandler:
             skip_dims = set()
 
         label_dict = OrderedDict()
+        selection_list = []
         for name, grouped_datum in zip(self.model_names, grouped_data):
             for _, sub_data in grouped_datum:
                 datum_iter = xarray_var_iter(
@@ -457,6 +515,7 @@ class VarHandler:
                     reverse_selections=True,
                 )
                 for _, selection, values in datum_iter:
+                    selection_list.append(selection)
                     label = make_label(self.var_name, selection, position="beside")
                     if label not in label_dict:
                         label_dict[label] = OrderedDict()
@@ -465,14 +524,16 @@ class VarHandler:
                     label_dict[label][name].append(values)
 
         y = self.y_start
-        for label, model_data in label_dict.items():
+        for idx, (label, model_data) in enumerate(label_dict.items()):
             for model_name, value_list in model_data.items():
                 if model_name:
                     row_label = "{}: {}".format(model_name, label)
                 else:
                     row_label = label
                 for values in value_list:
-                    yield y, row_label, label, values, self.model_color[model_name]
+                    yield y, row_label, label, selection_list[idx], values, self.model_color[
+                        model_name
+                    ]
                     y += self.chain_offset
                 y += self.var_offset
             y += self.group_offset
@@ -480,7 +541,7 @@ class VarHandler:
     def labels_ticks_and_vals(self):
         """Get labels, ticks, values, and colors for the variable."""
         y_ticks = defaultdict(list)
-        for y, label, _, vals, color in self.iterator():
+        for y, label, _, _, vals, color in self.iterator():
             y_ticks[label].append((y, vals, color))
         labels, ticks, vals, colors = [], [], [], []
         for label, data in y_ticks.items():
@@ -492,43 +553,46 @@ class VarHandler:
 
     def treeplot(self, qlist, hdi_prob):
         """Get data for each treeplot for the variable."""
-        for y, _, label, values, color in self.iterator():
+        for y, _, _, selection, values, color in self.iterator():
             ntiles = np.percentile(values.flatten(), qlist)
             ntiles[0], ntiles[-1] = hdi(values.flatten(), hdi_prob, multimodal=False)
-            yield y, label, ntiles, color
+            yield y, selection, ntiles, color
 
-    def ridgeplot(self, mult, ridgeplot_kind):
+    def ridgeplot(self, hdi_prob, mult, ridgeplot_kind):
         """Get data for each ridgeplot for the variable."""
-        xvals, yvals, pdfs, pdfs_q, colors = [], [], [], [], []
+        xvals, hdi_vals, yvals, pdfs, pdfs_q, colors = [], [], [], [], [], []
         for y, *_, values, color in self.iterator():
             yvals.append(y)
             colors.append(color)
             values = values.flatten()
             values = values[np.isfinite(values)]
 
+            if hdi_prob != 1:
+                hdi_ = hdi(values, hdi_prob, multimodal=False)
+            else:
+                hdi_ = min(values), max(values)
+
             if ridgeplot_kind == "auto":
                 kind = "hist" if np.all(np.mod(values, 1) == 0) else "density"
             else:
                 kind = ridgeplot_kind
 
             if kind == "hist":
-                bins = get_bins(values)
-                _, density, x = histogram(values, bins=bins)
-                density_q = density.cumsum() / density.sum()
+                _, density, x = histogram(values, bins=get_bins(values))
                 x = x[:-1]
             elif kind == "density":
-                density, lower, upper = _fast_kde(values)
-                density_q = density.cumsum() / density.sum()
-                x = np.linspace(lower, upper, len(density))
+                x, density = kde(values)
+
+            density_q = density.cumsum() / density.sum()
 
             xvals.append(x)
             pdfs.append(density)
-            pdfs_q.append((density_q))
+            pdfs_q.append(density_q)
+            hdi_vals.append(hdi_)
 
         scaling = max(np.max(j) for j in pdfs)
-        for y, x, pdf, pdf_q, color in zip(yvals, xvals, pdfs, pdfs_q, colors):
-            y = y * np.ones_like(x)
-            yield x, y, mult * pdf / scaling + y, pdf_q, color
+        for y, x, hdi_val, pdf, pdf_q, color in zip(yvals, xvals, hdi_vals, pdfs, pdfs_q, colors):
+            yield x, y, mult * pdf / scaling + y, hdi_val, pdf_q, color
 
     def ess(self):
         """Get effective n data for the variable."""
