@@ -9,7 +9,9 @@ import numpy as np
 import packaging
 import xarray as xr
 from matplotlib.colors import to_hex
-from scipy.stats import mode
+from scipy.stats import mode, rankdata
+from scipy.interpolate import CubicSpline
+
 
 from ..rcparams import rcParams
 from ..stats.density_utils import kde
@@ -94,7 +96,7 @@ def _scale_fig_size(figsize, textsize, rows=1, cols=1):
     return (width, height), ax_labelsize, titlesize, xt_labelsize, linewidth, markersize
 
 
-def default_grid(n_items, max_cols=4, min_cols=3):  # noqa: D202
+def default_grid(n_items, grid=None, max_cols=4, min_cols=3):  # noqa: D202
     """Make a grid for subplots.
 
     Tries to get as close to sqrt(n_items) x sqrt(n_items) as it can,
@@ -104,6 +106,8 @@ def default_grid(n_items, max_cols=4, min_cols=3):  # noqa: D202
     ----------
     n_items : int
         Number of panels required
+    grid : tuple
+        Number of rows and columns
     max_cols : int
         Maximum number of columns, inclusive
     min_cols : int
@@ -115,19 +119,28 @@ def default_grid(n_items, max_cols=4, min_cols=3):  # noqa: D202
         Rows and columns, so that rows * columns >= n_items
     """
 
-    def in_bounds(val):
-        return np.clip(val, min_cols, max_cols)
+    if grid is None:
 
-    if n_items <= max_cols:
-        return 1, n_items
-    ideal = in_bounds(round(n_items ** 0.5))
+        def in_bounds(val):
+            return np.clip(val, min_cols, max_cols)
 
-    for offset in (0, 1, -1, 2, -2):
-        cols = in_bounds(ideal + offset)
-        rows, extra = divmod(n_items, cols)
-        if extra == 0:
-            return rows, cols
-    return n_items // ideal + 1, ideal
+        if n_items <= max_cols:
+            return 1, n_items
+        ideal = in_bounds(round(n_items ** 0.5))
+
+        for offset in (0, 1, -1, 2, -2):
+            cols = in_bounds(ideal + offset)
+            rows, extra = divmod(n_items, cols)
+            if extra == 0:
+                return rows, cols
+        return n_items // ideal + 1, ideal
+    else:
+        rows, cols = grid
+        if rows * cols < n_items:
+            raise ValueError("The number of rows times columns is less than the number of subplots")
+        if (rows * cols) - n_items >= cols:
+            warnings.warn("The number of rows times columns is larger than necessary")
+        return rows, cols
 
 
 def selection_to_string(selection):
@@ -531,7 +544,7 @@ def get_plotting_function(plot_name, plot_module, backend):
     return plotting_method
 
 
-def calculate_point_estimate(point_estimate, values, bw="default", circular=False):
+def calculate_point_estimate(point_estimate, values, bw="default", circular=False, skipna=False):
     """Validate and calculate the point estimate.
 
     Parameters
@@ -550,6 +563,8 @@ def calculate_point_estimate(point_estimate, values, bw="default", circular=Fals
     circular: Optional[bool]
         If True, it interprets the values passed are from a circular variable measured in radians
         and a circular KDE is used. Only valid for 1D KDE. Defaults to False.
+    skipna=True,
+        If true ignores nan values when computing the hdi. Defaults to false.
 
     Returns
     -------
@@ -566,7 +581,10 @@ def calculate_point_estimate(point_estimate, values, bw="default", circular=Fals
             )
         )
     if point_estimate == "mean":
-        point_value = values.mean()
+        if skipna:
+            point_value = np.nanmean(values)
+        else:
+            point_value = np.mean(values)
     elif point_estimate == "mode":
         if isinstance(values[0], float):
             if bw == "default":
@@ -579,7 +597,10 @@ def calculate_point_estimate(point_estimate, values, bw="default", circular=Fals
         else:
             point_value = mode(values)[0][0]
     elif point_estimate == "median":
-        point_value = np.median(values)
+        if skipna:
+            point_value = np.nanmedian(values)
+        else:
+            point_value = np.median(values)
 
     return point_value
 
@@ -651,3 +672,17 @@ def set_bokeh_circular_ticks_labels(ax, hist, labels):
     )
 
     return ax
+
+
+def compute_ranks(ary):
+    """Compute ranks for continuos and discrete variables."""
+    if ary.dtype.kind == "i":
+        ary_shape = ary.shape
+        ary = ary.flatten()
+        min_ary, max_ary = min(ary), max(ary)
+        x = np.linspace(min_ary, max_ary, len(ary))
+        csi = CubicSpline(x, ary)
+        ary = csi(np.linspace(min_ary + 0.001, max_ary - 0.001, len(ary))).reshape(ary_shape)
+    ranks = rankdata(ary, method="average").reshape(ary.shape)
+
+    return ranks
