@@ -11,10 +11,12 @@ def plot_posterior(
     filter_vars=None,
     transform=None,
     coords=None,
+    grid=None,
     figsize=None,
     textsize=None,
     hdi_prob=None,
     multimodal=False,
+    skipna=False,
     round_to=None,
     point_estimate="auto",
     group="posterior",
@@ -50,6 +52,9 @@ def plot_posterior(
         Function to transform data (defaults to None i.e.the identity function)
     coords: mapping, optional
         Coordinates of var_names to be plotted. Passed to `Dataset.sel`
+    grid : tuple
+        Number of rows and columns. Defaults to None, the rows and columns are
+        automatically inferred.
     figsize: tuple
         Figure size. If None it will be defined automatically.
     textsize: float
@@ -61,6 +66,8 @@ def plot_posterior(
     multimodal: bool
         If true (default) it may compute more than one credible interval if the distribution is
         multimodal and the modes are well separated.
+    skipna : bool
+        If true ignores nan values when computing the hdi and point estimates. Defaults to false.
     round_to: int, optional
         Controls formatting of floats. Defaults to 2 or the integer part, whichever is bigger.
     point_estimate: Optional[str]
@@ -217,7 +224,7 @@ def plot_posterior(
         "plot_posterior",
     )
     length_plotters = len(plotters)
-    rows, cols = default_grid(length_plotters)
+    rows, cols = default_grid(length_plotters, grid=grid)
 
     posteriorplot_kwargs = dict(
         ax=ax,
@@ -234,6 +241,7 @@ def plot_posterior(
         round_to=round_to,
         hdi_prob=hdi_prob,
         multimodal=multimodal,
+        skipna=skipna,
         textsize=textsize,
         ref_val=ref_val,
         rope=rope,
