@@ -62,7 +62,15 @@ def bfmi(data):
     return _bfmi(dataset.energy)
 
 
-def ess(data, *, var_names=None, method="bulk", relative=False, prob=None):
+def ess(
+    data,
+    *,
+    var_names=None,
+    method="bulk",
+    relative=False,
+    prob=None,
+    dask_kwargs=None,
+):
     r"""Calculate estimate of the effective sample size (ess).
 
     Parameters
@@ -93,6 +101,8 @@ def ess(data, *, var_names=None, method="bulk", relative=False, prob=None):
         `ress = ess / n`
     prob : float, or tuple of two floats, optional
         probability value for "tail", "quantile" or "local" ess functions.
+    dask_kwargs : dict, optional
+        Dask related kwargs passed to :func:`~arviz.wrap_xarray_ufunc`.
 
     Returns
     -------
@@ -161,9 +171,7 @@ def ess(data, *, var_names=None, method="bulk", relative=False, prob=None):
     }
 
     if method not in methods:
-        raise TypeError(
-            "ess method {} not found. Valid methods are:\n{}".format(method, "\n    ".join(methods))
-        )
+        raise TypeError(f"ess method {method} not found. Valid methods are:\n{', '.join(methods)}")
     ess_func = methods[method]
 
     if (method == "quantile") and prob is None:
@@ -192,10 +200,16 @@ def ess(data, *, var_names=None, method="bulk", relative=False, prob=None):
 
     ufunc_kwargs = {"ravel": False}
     func_kwargs = {"relative": relative} if prob is None else {"prob": prob, "relative": relative}
-    return _wrap_xarray_ufunc(ess_func, dataset, ufunc_kwargs=ufunc_kwargs, func_kwargs=func_kwargs)
+    return _wrap_xarray_ufunc(
+        ess_func,
+        dataset,
+        ufunc_kwargs=ufunc_kwargs,
+        func_kwargs=func_kwargs,
+        dask_kwargs=dask_kwargs,
+    )
 
 
-def rhat(data, *, var_names=None, method="rank"):
+def rhat(data, *, var_names=None, method="rank", dask_kwargs=None):
     r"""Compute estimate of rank normalized splitR-hat for a set of traces.
 
     The rank normalized R-hat diagnostic tests for lack of convergence by comparing the variance
@@ -222,6 +236,8 @@ def rhat(data, *, var_names=None, method="rank"):
         - "folded"
         - "z_scale"
         - "identity"
+    dask_kwargs : dict, optional
+        Dask related kwargs passed to :func:`~arviz.wrap_xarray_ufunc`.
 
     Returns
     -------
@@ -275,9 +291,7 @@ def rhat(data, *, var_names=None, method="rank"):
     }
     if method not in methods:
         raise TypeError(
-            "R-hat method {} not found. Valid methods are:\n{}".format(
-                method, "\n    ".join(methods)
-            )
+            f"R-hat method {method} not found. Valid methods are:\n{', '.join(methods)}"
         )
     rhat_func = methods[method]
 
@@ -300,11 +314,15 @@ def rhat(data, *, var_names=None, method="rank"):
     ufunc_kwargs = {"ravel": False}
     func_kwargs = {}
     return _wrap_xarray_ufunc(
-        rhat_func, dataset, ufunc_kwargs=ufunc_kwargs, func_kwargs=func_kwargs
+        rhat_func,
+        dataset,
+        ufunc_kwargs=ufunc_kwargs,
+        func_kwargs=func_kwargs,
+        dask_kwargs=dask_kwargs,
     )
 
 
-def mcse(data, *, var_names=None, method="mean", prob=None):
+def mcse(data, *, var_names=None, method="mean", prob=None, dask_kwargs=None):
     """Calculate Markov Chain Standard Error statistic.
 
     Parameters
@@ -325,6 +343,8 @@ def mcse(data, *, var_names=None, method="mean", prob=None):
 
     prob : float
         Quantile information.
+    dask_kwargs : dict, optional
+        Dask related kwargs passed to :func:`~arviz.wrap_xarray_ufunc`.
 
     Returns
     -------
@@ -387,7 +407,11 @@ def mcse(data, *, var_names=None, method="mean", prob=None):
     ufunc_kwargs = {"ravel": False}
     func_kwargs = {} if prob is None else {"prob": prob}
     return _wrap_xarray_ufunc(
-        mcse_func, dataset, ufunc_kwargs=ufunc_kwargs, func_kwargs=func_kwargs
+        mcse_func,
+        dataset,
+        ufunc_kwargs=ufunc_kwargs,
+        func_kwargs=func_kwargs,
+        dask_kwargs=dask_kwargs,
     )
 
 
