@@ -1,5 +1,4 @@
 """Stats-utility functions for ArviZ."""
-import logging
 import warnings
 from collections.abc import Sequence
 from copy import copy as _copy
@@ -8,13 +7,14 @@ from copy import deepcopy as _deepcopy
 import numpy as np
 import pandas as pd
 from scipy.fftpack import next_fast_len
+from scipy.interpolate import CubicSpline
 from scipy.stats.mstats import mquantiles
 from xarray import apply_ufunc
 
-from ..utils import conditional_jit, conditional_vect
+from arviz import _log
+from ..utils import conditional_jit, conditional_vect, conditional_dask
 from .density_utils import histogram as _histogram
 
-_log = logging.getLogger(__name__)
 
 __all__ = ["autocorr", "autocov", "ELPDData", "make_ufunc", "wrap_xarray_ufunc"]
 
@@ -129,8 +129,8 @@ def make_ufunc(
                 n_dims_out = -len(out_shape)
         elif check_shape:
             if out.shape != arys[-1].shape[:-n_dims]:
-                msg = "Shape incorrect for `out`: {}.".format(out.shape)
-                msg += " Correct shape is {}".format(arys[-1].shape[:-n_dims])
+                msg = f"Shape incorrect for `out`: {out.shape}."
+                msg += f" Correct shape is {arys[-1].shape[:-n_dims]}"
                 raise TypeError(msg)
         for idx in np.ndindex(out.shape[:n_dims_out]):
             arys_idx = [ary[idx].ravel() if ravel else ary[idx] for ary in arys]
@@ -156,10 +156,10 @@ def make_ufunc(
                     raise_error = True
             else:
                 raise_error = True
-                out_shape = "not tuple, type={}".format(type(out))
+                out_shape = "not tuple, type={type(out)}"
             if raise_error:
-                msg = "Shapes incorrect for `out`: {}.".format(out_shape)
-                msg += " Correct shapes are {}".format(correct_shape)
+                msg = f"Shapes incorrect for `out`: {out_shape}."
+                msg += f" Correct shapes are {correct_shape}"
                 raise TypeError(msg)
         for idx in np.ndindex(element_shape):
             arys_idx = [ary[idx].ravel() if ravel else ary[idx] for ary in arys]
@@ -177,8 +177,15 @@ def make_ufunc(
     return ufunc
 
 
+@conditional_dask
 def wrap_xarray_ufunc(
-    ufunc, *datasets, ufunc_kwargs=None, func_args=None, func_kwargs=None, **kwargs
+    ufunc,
+    *datasets,
+    ufunc_kwargs=None,
+    func_args=None,
+    func_kwargs=None,
+    dask_kwargs=None,
+    **kwargs,
 ):
     """Wrap make_ufunc with xarray.apply_ufunc.
 
@@ -198,6 +205,9 @@ def wrap_xarray_ufunc(
     func_kwargs : dict
         Keyword arguments passed to 'ufunc'.
             - 'out_shape', int, by default None
+    dask_kwargs : dict
+        Dask related kwargs passed to :func:`xarray:xarray.apply_ufunc`.
+        Use :meth:`~arviz.Dask.enable_dask` to set default kwargs.
     **kwargs
         Passed to xarray.apply_ufunc.
 
@@ -212,6 +222,8 @@ def wrap_xarray_ufunc(
         func_args = tuple()
     if func_kwargs is None:
         func_kwargs = {}
+    if dask_kwargs is None:
+        dask_kwargs = {}
 
     kwargs.setdefault(
         "input_core_dims", tuple(("chain", "draw") for _ in range(len(func_args) + len(datasets)))
@@ -221,7 +233,9 @@ def wrap_xarray_ufunc(
 
     callable_ufunc = make_ufunc(ufunc, **ufunc_kwargs)
 
-    return apply_ufunc(callable_ufunc, *datasets, *func_args, kwargs=func_kwargs, **kwargs)
+    return apply_ufunc(
+        callable_ufunc, *datasets, *func_args, kwargs=func_kwargs, **dask_kwargs, **kwargs
+    )
 
 
 def update_docstring(ufunc, func, n_output=1):
@@ -244,13 +258,14 @@ def update_docstring(ufunc, func, n_output=1):
     ufunc.__doc__ += "\n\n"
     input_core_dims = 'tuple(("chain", "draw") for _ in range(n_args))'
     if n_output > 1:
-        output_core_dims = " tuple([] for _ in range({}))".format(n_output)
-        msg = "xr.apply_ufunc(ufunc, dataset, input_core_dims={}, output_core_dims={})"
-        ufunc.__doc__ += msg.format(input_core_dims, output_core_dims)
+        output_core_dims = f" tuple([] for _ in range({n_output}))"
+        msg = f"xr.apply_ufunc(ufunc, dataset, input_core_dims={input_core_dims}, "
+        msg += f"output_core_dims={ output_core_dims})"
+        ufunc.__doc__ += msg
     else:
         output_core_dims = ""
-        msg = "xr.apply_ufunc(ufunc, dataset, input_core_dims={})"
-        ufunc.__doc__ += msg.format(input_core_dims)
+        msg = f"xr.apply_ufunc(ufunc, dataset, input_core_dims={input_core_dims})"
+        ufunc.__doc__ += msg
     ufunc.__doc__ += "\n\n"
     ufunc.__doc__ += "For example: np.std(data, ddof=1) --> n_args=2"
     if docstring:
@@ -381,8 +396,8 @@ def not_valid(ary, check_nan=True, check_shape=True, nan_kwargs=None, shape_kwar
 
         min_chains = shape_kwargs.get("min_chains", 2)
         min_draws = shape_kwargs.get("min_draws", 4)
-        error_msg = "Shape validation failed: input_shape: {}, minimum_shape: (chains={}, draws={})"
-        error_msg = error_msg.format(shape, min_chains, min_draws)
+        error_msg = f"Shape validation failed: input_shape: {shape}, "
+        error_msg += f"minimum_shape: (chains={min_chains}, draws={min_draws})"
 
         chain_error = ((min_chains > 1) and (len(shape) < 2)) or (shape[0] < min_chains)
         draw_error = ((len(shape) < 2) and (shape[0] < min_draws)) or (
@@ -409,14 +424,14 @@ def get_log_likelihood(idata, var_name=None):
         var_names = list(idata.log_likelihood.data_vars)
         if len(var_names) > 1:
             raise TypeError(
-                "Found several log likelihood arrays {}, var_name cannot be None".format(var_names)
+                f"Found several log likelihood arrays {var_names}, var_name cannot be None"
             )
         return idata.log_likelihood[var_names[0]]
     else:
         try:
             log_likelihood = idata.log_likelihood[var_name]
         except KeyError as err:
-            raise TypeError("No log likelihood data named {} found".format(var_name)) from err
+            raise TypeError(f"No log likelihood data named {var_name} found") from err
         return log_likelihood
 
 
@@ -447,7 +462,7 @@ class ELPDData(pd.Series):  # pylint: disable=too-many-ancestors
         if kind not in ("loo", "waic"):
             raise ValueError("Invalid ELPDData object")
 
-        scale_str = SCALE_DICT[self["{}_scale".format(kind)]]
+        scale_str = SCALE_DICT[self[f"{kind}_scale"]]
         padding = len(scale_str) + len(kind) + 1
         base = BASE_FMT.format(padding, padding - 2)
         base = base.format(
@@ -456,7 +471,7 @@ class ELPDData(pd.Series):  # pylint: disable=too-many-ancestors
             scale=scale_str,
             n_samples=self.n_samples,
             n_points=self.n_data_points,
-            *self.values
+            *self.values,
         )
 
         if self.warning:
@@ -540,3 +555,16 @@ def _circular_standard_deviation(samples, high=2 * np.pi, low=0, skipna=False, a
     c_c = np.cos(ang).mean(axis=axis)
     r_r = np.hypot(s_s, c_c)
     return ((high - low) / 2.0 / np.pi) * np.sqrt(-2 * np.log(r_r))
+
+
+def smooth_data(obs_vals, pp_vals):
+    """Smooth data, helper function for discrete data in plot_pbv, loo_pit and plot_loo_pit."""
+    x = np.linspace(0, 1, len(obs_vals))
+    csi = CubicSpline(x, obs_vals)
+    obs_vals = csi(np.linspace(0.01, 0.99, len(obs_vals)))
+
+    x = np.linspace(0, 1, pp_vals.shape[1])
+    csi = CubicSpline(x, pp_vals, axis=1)
+    pp_vals = csi(np.linspace(0.01, 0.99, pp_vals.shape[1]))
+
+    return obs_vals, pp_vals
