@@ -16,6 +16,7 @@ from ...plots.plot_utils import (
     vectorized_to_hex,
     xarray_to_ndarray,
     xarray_var_iter,
+    compute_ranks,
 )
 from ...rcparams import rc_context
 from ...stats.density_utils import get_bins
@@ -23,6 +24,10 @@ from ...utils import get_coords
 from ..helpers import running_on_ci
 
 
+# Check if Bokeh is installed
+bokeh_installed = importlib.util.find_spec("bokeh") is not None  # pylint: disable=invalid-name
+
+
 @pytest.mark.parametrize(
     "value, default, expected",
     [
@@ -200,7 +205,7 @@ def test_filter_plotter_list_warning():
 
 
 @pytest.mark.skipif(
-    (importlib.util.find_spec("bokeh") is None) & ~running_on_ci(),
+    not (bokeh_installed or running_on_ci()),
     reason="test requires bokeh which is not installed",
 )
 def test_bokeh_import():
@@ -278,7 +283,7 @@ def test_mpl_dealiase_sel_kwargs():
 
 
 @pytest.mark.skipif(
-    (importlib.util.find_spec("bokeh") is None) & ~running_on_ci(),
+    not (bokeh_installed or running_on_ci()),
     reason="test requires bokeh which is not installed",
 )
 def test_bokeh_dealiase_sel_kwargs():
@@ -302,12 +307,8 @@ def test_bokeh_dealiase_sel_kwargs():
     assert res["line_color"] == "red"
 
 
-# Check if Bokeh is installed
-bokeh_installed = importlib.util.find_spec("bokeh") is not None  # pylint: disable=invalid-name
-
-
 @pytest.mark.skipif(
-    not (bokeh_installed | running_on_ci()),
+    not (bokeh_installed or running_on_ci()),
     reason="test requires bokeh which is not installed",
 )
 def test_set_bokeh_circular_ticks_labels():
@@ -322,3 +323,20 @@ def test_set_bokeh_circular_ticks_labels():
     assert len(renderers) == 3
     assert renderers[2].data_source.data["text"] == labels
     assert len(renderers[0].data_source.data["start_angle"]) == len(labels)
+
+
+def test_compute_ranks():
+    pois_data = np.array([[5, 4, 1, 4, 0], [2, 8, 2, 1, 1]])
+    expected = np.array([[9.0, 7.0, 3.0, 8.0, 1.0], [5.0, 10.0, 6.0, 2.0, 4.0]])
+    ranks = compute_ranks(pois_data)
+    np.testing.assert_equal(ranks, expected)
+
+    norm_data = np.array(
+        [
+            [0.2644187, -1.3004813, -0.80428456, 1.01319068, 0.62631143],
+            [1.34498018, -0.13428933, -0.69855487, -0.9498981, -0.34074092],
+        ]
+    )
+    expected = np.array([[7.0, 1.0, 3.0, 9.0, 8.0], [10.0, 6.0, 4.0, 2.0, 5.0]])
+    ranks = compute_ranks(norm_data)
+    np.testing.assert_equal(ranks, expected)
