@@ -112,10 +112,26 @@ def test_plot_density_no_subset():
             "c": np.random.normal(size=200),
         }
     )
-    axes = plot_density([model_ab, model_bc])
+    axes = plot_density([model_ab, model_bc], backend="bokeh", show=False)
     assert axes.size == 3
 
 
+def test_plot_density_one_var():
+    """Test plot_density works when there is only one variable (#1401)."""
+    model_ab = from_dict(
+        {
+            "a": np.random.normal(size=200),
+        }
+    )
+    model_bc = from_dict(
+        {
+            "a": np.random.normal(size=200),
+        }
+    )
+    axes = plot_density([model_ab, model_bc], backend="bokeh", show=False)
+    assert axes.size == 1
+
+
 def test_plot_density_bad_kwargs(models):
     obj = [getattr(models, model_fit) for model_fit in ["model_1", "model_2"]]
     with pytest.raises(ValueError):
@@ -310,16 +326,6 @@ def test_plot_compare(models, kwargs):
     assert axes
 
 
-def test_plot_compare_manual(models):
-    """Test compare plot without scale column"""
-    model_compare = compare({"Model 1": models.model_1, "Model 2": models.model_2})
-
-    # remove "scale" column
-    del model_compare["loo_scale"]
-    axes = plot_compare(model_compare, backend="bokeh", show=False)
-    assert axes
-
-
 def test_plot_compare_no_ic(models):
     """Check exception is raised if model_compare doesn't contain a valid information criterion"""
     model_compare = compare({"Model 1": models.model_1, "Model 2": models.model_2})
@@ -595,7 +601,12 @@ def test_plot_joint_bad(models):
         {"color": "obs_dim", "legend": True, "hover_label": True},
         {"color": "blue", "coords": {"obs_dim": slice(2, 4)}},
         {"color": np.random.uniform(size=8), "show_bins": True},
-        {"color": np.random.uniform(size=(8, 3)), "show_bins": True, "annotate": True},
+        {
+            "color": np.random.uniform(size=(8, 3)),
+            "show_bins": True,
+            "show_hlines": True,
+            "threshold": 1,
+        },
     ],
 )
 @pytest.mark.parametrize("input_type", ["elpd_data", "data_array", "array"])
@@ -622,7 +633,12 @@ def test_plot_khat(models, input_type, kwargs):
         {"color": "dim2", "legend": True, "hover_label": True},
         {"color": "blue", "coords": {"dim2": slice(2, 4)}},
         {"color": np.random.uniform(size=35), "show_bins": True},
-        {"color": np.random.uniform(size=(35, 3)), "show_bins": True, "annotate": True},
+        {
+            "color": np.random.uniform(size=(35, 3)),
+            "show_bins": True,
+            "show_hlines": True,
+            "threshold": 1,
+        },
     ],
 )
 @pytest.mark.parametrize("input_type", ["elpd_data", "data_array", "array"])
@@ -644,9 +660,9 @@ def test_plot_khat_multidim(multidim_models, input_type, kwargs):
     assert axes
 
 
-def test_plot_khat_annotate():
+def test_plot_khat_threshold():
     khats = np.array([0, 0, 0.6, 0.6, 0.8, 0.9, 0.9, 2, 3, 4, 1.5])
-    axes = plot_khat(khats, annotate=True, backend="bokeh", show=False)
+    axes = plot_khat(khats, threshold=1, backend="bokeh", show=False)
     assert axes
 
 
@@ -860,9 +876,16 @@ def test_plot_violin_discrete(discrete_model):
 
 @pytest.mark.parametrize("kind", ["kde", "cumulative", "scatter"])
 @pytest.mark.parametrize("alpha", [None, 0.2, 1])
-def test_plot_ppc(models, kind, alpha):
+@pytest.mark.parametrize("observed", [True, False])
+def test_plot_ppc(models, kind, alpha, observed):
     axes = plot_ppc(
-        models.model_1, kind=kind, alpha=alpha, random_seed=3, backend="bokeh", show=False
+        models.model_1,
+        kind=kind,
+        alpha=alpha,
+        observed=observed,
+        random_seed=3,
+        backend="bokeh",
+        show=False,
     )
     assert axes
 
@@ -1000,6 +1023,14 @@ def test_plot_posterior_point_estimates(models, point_estimate):
     assert axes.shape == (1, 2)
 
 
+def test_plot_posterior_skipna():
+    sample = np.linspace(0, 1)
+    sample[:10] = np.nan
+    plot_posterior({"a": sample}, backend="bokeh", show=False, skipna=True)
+    with pytest.raises(ValueError):
+        plot_posterior({"a": sample}, backend="bokeh", show=False, skipna=False)
+
+
 @pytest.mark.parametrize(
     "kwargs",
     [
@@ -1007,8 +1038,19 @@ def test_plot_posterior_point_estimates(models, point_estimate):
         {"var_names": "mu"},
         {"var_names": ("mu", "tau"), "coords": {"theta_dim_0": [0, 1]}},
         {"var_names": "mu", "ref_line": True},
+        {
+            "var_names": "mu",
+            "ref_line_kwargs": {"line_width": 2, "line_color": "red"},
+            "bar_kwargs": {"width": 50},
+        },
         {"var_names": "mu", "ref_line": False},
         {"var_names": "mu", "kind": "vlines"},
+        {
+            "var_names": "mu",
+            "kind": "vlines",
+            "vlines_kwargs": {"line_width": 0},
+            "marker_vlines_kwargs": {"radius": 20},
+        },
     ],
 )
 def test_plot_rank(models, kwargs):
