@@ -163,7 +163,7 @@ def test_compare_unknown_ic_and_method(centered_eight, non_centered_eight):
 def test_compare_different(centered_eight, non_centered_eight, ic, method, scale):
     model_dict = {"centered": centered_eight, "non_centered": non_centered_eight}
     weight = compare(model_dict, ic=ic, method=method, scale=scale)["weight"]
-    assert weight["non_centered"] >= weight["centered"]
+    assert weight["non_centered"] > weight["centered"]
     assert_allclose(np.sum(weight), 1.0)
 
 
@@ -174,7 +174,7 @@ def test_compare_different_multidim(multidim_models, ic, method):
     weight = compare(model_dict, ic=ic, method=method)["weight"]
 
     # this should hold because the same seed is always used
-    assert weight["model_1"] >= weight["model_2"]
+    assert weight["model_1"] > weight["model_2"]
     assert_allclose(np.sum(weight), 1.0)
 
 
@@ -192,6 +192,12 @@ def test_compare_different_size(centered_eight, non_centered_eight):
         compare(model_dict, ic="waic", method="stacking")
 
 
+def test_summary_ndarray():
+    array = np.random.randn(4, 100, 2)
+    summary_df = summary(array)
+    assert summary_df.shape
+
+
 @pytest.mark.parametrize("var_names_expected", ((None, 10), ("mu", 1), (["mu", "tau"], 2)))
 def test_summary_var_names(centered_eight, var_names_expected):
     var_names, expected = var_names_expected
@@ -199,6 +205,34 @@ def test_summary_var_names(centered_eight, var_names_expected):
     assert len(summary_df.index) == expected
 
 
+@pytest.mark.parametrize("missing_groups", (None, "posterior", "prior"))
+def test_summary_groups(centered_eight, missing_groups):
+    if missing_groups == "posterior":
+        centered_eight = deepcopy(centered_eight)
+        del centered_eight.posterior
+    elif missing_groups == "prior":
+        centered_eight = deepcopy(centered_eight)
+        del centered_eight.posterior
+        del centered_eight.prior
+    if missing_groups == "prior":
+        with pytest.warns(UserWarning):
+            summary_df = summary(centered_eight)
+    else:
+        summary_df = summary(centered_eight)
+    assert summary_df.shape
+
+
+def test_summary_group_argument(centered_eight):
+    summary_df_posterior = summary(centered_eight, group="posterior")
+    summary_df_prior = summary(centered_eight, group="prior")
+    assert list(summary_df_posterior.index) != list(summary_df_prior.index)
+
+
+def test_summary_wrong_group(centered_eight):
+    with pytest.raises(TypeError, match=r"InferenceData does not contain group: InvalidGroup"):
+        summary(centered_eight, group="InvalidGroup")
+
+
 METRICS_NAMES = [
     "mean",
     "sd",
@@ -298,13 +332,19 @@ def test_summary_skip_nan(centered_eight):
 
 @pytest.mark.parametrize("fmt", [1, "bad_fmt"])
 def test_summary_bad_fmt(centered_eight, fmt):
-    with pytest.raises(TypeError):
+    with pytest.raises(TypeError, match="Invalid format"):
         summary(centered_eight, fmt=fmt)
 
 
+@pytest.mark.parametrize("kind", [1, "bad_kind"])
+def test_summary_bad_kind(centered_eight, kind):
+    with pytest.raises(TypeError, match="Invalid kind"):
+        summary(centered_eight, kind=kind)
+
+
 @pytest.mark.parametrize("order", [1, "bad_order"])
 def test_summary_bad_unpack_order(centered_eight, order):
-    with pytest.raises(TypeError):
+    with pytest.raises(TypeError, match="Invalid order"):
         summary(centered_eight, order=order)
 
 
@@ -553,6 +593,15 @@ def test_loo_pit_multidim(multidim_models, args):
     assert np.all((loo_pit_data >= 0) & (loo_pit_data <= 1))
 
 
+def test_loo_pit_multi_lik():
+    idata = load_arviz_data("radon")
+    idata.log_likelihood["by_county"] = (
+        idata.log_likelihood["y"].groupby(idata.constant_data["county_idx"]).sum()
+    )
+    loo_pit_data = loo_pit(idata, y="y")
+    assert np.all((loo_pit_data >= 0) & (loo_pit_data <= 1))
+
+
 @pytest.mark.parametrize("input_type", ["idataarray", "idatanone_ystr", "yarr_yhatnone"])
 def test_loo_pit_bad_input(centered_eight, input_type):
     """Test incompatible input combinations."""
