@@ -357,7 +357,8 @@ class TestDataPyMC3:
         assert not fails
         assert inference_data.observed_data.value.dtype.kind == "f"
 
-    def test_multiobservedrv_to_observed_data(self):
+    @pytest.mark.parametrize("multiobs", (True, False))
+    def test_multiobservedrv_to_observed_data(self, multiobs):
         # fake regression data, with weights (W)
         np.random.seed(2019)
         N = 100
@@ -379,16 +380,18 @@ class TestDataPyMC3:
                 "y_logp", weighted_normal, observed={"y": Y, "w": W}
             )
             trace = pm.sample(20, tune=20)
-            idata = from_pymc3(trace)
+            idata = from_pymc3(trace, density_dist_obs=multiobs)
+        multiobs_str = "" if multiobs else "~"
         test_dict = {
             "posterior": ["a", "b", "sigma"],
             "sample_stats": ["lp"],
             "log_likelihood": ["y_logp"],
-            "observed_data": ["y", "w"],
+            f"{multiobs_str}observed_data": ["y", "w"],
         }
         fails = check_multiple_attrs(test_dict, idata)
         assert not fails
-        assert idata.observed_data.y.dtype.kind == "f"
+        if multiobs:
+            assert idata.observed_data.y.dtype.kind == "f"
 
     def test_single_observation(self):
         with pm.Model():
@@ -532,6 +535,24 @@ class TestDataPyMC3:
         fails = check_multiple_attrs(test_dict, inference_data)
         assert not fails
 
+    def test_multivariate_observations(self):
+        coords = {"direction": ["x", "y", "z"], "experiment": np.arange(20)}
+        data = np.random.multinomial(20, [0.2, 0.3, 0.5], size=20)
+        with pm.Model(coords=coords):
+            p = pm.Beta("p", 1, 1, shape=(3,))
+            pm.Multinomial("y", 20, p, dims=("experiment", "direction"), observed=data)
+            idata = pm.sample(draws=50, tune=100, return_inferencedata=True)
+        test_dict = {
+            "posterior": ["p"],
+            "sample_stats": ["lp"],
+            "log_likelihood": ["y"],
+            "observed_data": ["y"],
+        }
+        fails = check_multiple_attrs(test_dict, idata)
+        assert not fails
+        assert "direction" not in idata.log_likelihood.dims
+        assert "direction" in idata.observed_data.dims
+
 
 class TestPyMC3WarmupHandling:
     @pytest.mark.skipif(
